==> lxqt-session-0.15.0.tar.xz: lxqt-session-0.15.0/lxqt-leave/translations/lxqt-leave_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>LeaveDialog</name>
    <message>
        <location filename="../leavedialog.ui" line="20"/>
        <source>Leave</source>
        <translation>Verlaten</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="71"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;What do you want the computer to do?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Wat wilt u, dat de computer doet?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="51"/>
        <source>Logout</source>
        <translation>Afmelden</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="69"/>
        <source>Reboot</source>
        <translation>Herstarten</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="56"/>
        <source>Shutdown</source>
        <translation>Afsluiten</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="61"/>
        <source>Suspend</source>
        <translation>Pauzestand</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="66"/>
        <source>Lock screen</source>
        <translation>Beeldscherm vergrendelen</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="74"/>
        <source>Hibernate</source>
        <translation>Slaapstand</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="51"/>
        <source>Cancel</source>
        <translation>Afbreken</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>Logout.</source>
        <translation>Afmelden.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>Lockscreen.</source>
        <translation>Scherm vergrendelen.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="64"/>
        <source>Suspend.</source>
        <translation>Pauzestand.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>Hibernate.</source>
        <translation>Slaapstand.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>Shutdown.</source>
        <translation>Afsluiten.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Reboot.</source>
        <translation>Herstarten.</translation>
    </message>
</context>
</TS>

==> lxqt-session_1.1.1.orig.tar.xz: lxqt-session-1.1.1/lxqt-leave/translations/lxqt-leave_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>LeaveDialog</name>
    <message>
        <location filename="../leavedialog.ui" line="20"/>
        <source>Leave</source>
        <translation>Afsluiten</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="71"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;What do you want the computer to do?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Wat wilt u dat de computer doet?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="55"/>
        <source>Logout</source>
        <translation>Afmelden</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="73"/>
        <source>Reboot</source>
        <translation>Herstarten</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="60"/>
        <source>Shutdown</source>
        <translation>Afsluiten</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="65"/>
        <source>Suspend</source>
        <translation>Pauzestand</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="70"/>
        <source>Lock screen</source>
        <translation>Beeldscherm vergrendelen</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="78"/>
        <source>Hibernate</source>
        <translation>Slaapstand</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="51"/>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="60"/>
        <source>Logout.</source>
        <translation>Afmelden.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="63"/>
        <source>Lockscreen.</source>
        <translation>Scherm vergrendelen.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>Suspend.</source>
        <translation>Pauzestand.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="69"/>
        <source>Hibernate.</source>
        <translation>Slaapstand.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>Shutdown.</source>
        <translation>Afsluiten.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>Reboot.</source>
        <translation>Herstarten.</translation>
    </message>
</context>
</TS>
